"use strict";

/*

su-extensions/disqus/disqus.js

Implements Disqus.com.

See extension.js for details.

*/

// Actual class let's go
function ScDisqus()
{
	this.url = "";
	this.identifier = "";

	this.process = function()
	{
		_process();
	}

	this.onDisqusLoad = function()
	{
		_onDisqusLoad();
	}

	var _this = this;
	var _disqusLoaded = false;
	var _commentsDiv = null;
	var _disableButton = null;
	
	function _process()
	{
		// If no Disqus define at all, complain and return
		if( SC_DISQUS_ENABLE == undefined )
		{
			console.log( "Disqus disabled due to missing define in site config" );
			return;
		}

		// If Disqus disabled by config, complain and return
		if( SC_DISQUS_ENABLE == false )
		{
			console.log( "Disqus disabled by site config" );
			return;
		}

		// Get comment thread div
		_commentsDiv = document.querySelector( ".comments" );

		// If no Disqus on this page, return
		if( _commentsDiv == null ) return;

		// If user has disabled Disqus, "User disable" it and return
		if( localStorage.getItem( "sc_disqusEnable" ) == "false" )
		{
			_disable();
			return;
		}

		// Turn Disqus on
		_enable();
	}

	function _disable()
	{
		// Flag Disqus disabled
		localStorage.setItem( "sc_disqusEnable", "false" );

		// Set commentsDiv inner HTML to disable button
		_commentsDiv.innerHTML = `
			<input type="button" class="enable-disqus-button" value="Load Disqus Comments">
		`;

		// Make enable button call _enable() :D
		var enableDisqusButton = document.querySelector( ".enable-disqus-button" );
		enableDisqusButton.onclick = _enable;
	}

	function _enable()
	{
		// Flag that Disqus is enabled
		localStorage.setItem( "sc_disqusEnable", "true" );

		// Get thread ID from comments div
		var threadID = _commentsDiv.getAttribute( "data-thread-id" );

		// Set initial value for comments div
		_commentsDiv.innerHTML = `
			<div class="disable-disqus-button-container"><input type="button" class="disable-disqus-button" value="Turn off Disqus Comments"></div>
			<div id="disqus_thread"></div>
			<noscript>Please enable JavaScript to view the <a href="https://disqus.com/?ref_noscript">comments powered by Disqus.</a></noscript>
		`;

		// Set disqus URL and ID
		_this.url = "https://" + SC_DISQUS_CANON_DOMAIN + window.location.pathname;
		_this.identifier = threadID;	

		// If Disqus not loaded yet, load it now
		if( _disqusLoaded == false )
		{
			(function() { // DON'T EDIT BELOW THIS LINE
				var d = document, s = d.createElement('script');
				s.src = 'https://' + SC_DISQUS_USER_DOMAIN + '.disqus.com/embed.js';
				s.setAttribute('data-timestamp', +new Date());
				(d.head || d.body).appendChild(s);
				})();
		}
		// If Disqus already loaded, reset instead
		else if( _disqusLoaded == true )
		{
			_disqusLoaded = false;

			DISQUS.reset({
				reload: true,
				config: function () {  
				  this.page.identifier = _this.identifier;  
				  this.page.url = _this.url;
				}
			  });
		}
	}

	function _onDisqusLoad()
	{
		_disqusLoaded = true;
		_disableButton = document.querySelector( ".disable-disqus-button" );
		_disableButton.onclick = _disable;
	}

	Object.seal( this );
}

var scDisqus = new ScDisqus();

window.disqus_config = function()
{
	this.callbacks.onReady.push( scDisqus.onDisqusLoad );
	this.page.url = scDisqus.url;  // Replace PAGE_URL with your page's canonical URL variable
	this.page.identifier = scDisqus.identifier; // Replace PAGE_IDENTIFIER with your page's unique identifier variables
}
